SFC_RULES_3x3_PEANO, SFC_RULES_3x3_MEANDER and SFC_RULES_3x3_COMBINED, SFC_RULES_MEANDER_4x4_1, SFC_RULES_MEANDER_4x4_2 also contain the "flipped" expansion rules.
SFC_RULES_3x3_COMBINED is a combination of SFC_RULES_3x3_PEANO and SFC_RULES_3x3_MEANDER where
in SFC_RULES_3x3_PEANO, J is replaced by its original pattern I.
SFC_RULES_4x4_MEANDER_1 and SFC_RULES_4x4_MEANDER_2 are extension rules of Meander curves (3x3)
on the 4x4 mode It is only for the demonstration purpose, thus only I/R/L are supported.