View source: R/sfc_3x3_combined.R
| sfc_3x3_combined | R Documentation |
General 3x3 space-filling curves
sfc_3x3_combined(seed, level = 0, rot = 0L, flip = FALSE)
## S4 method for signature 'sfc_3x3_combined'
sfc_expand(p, code = NULL, flip = FALSE)
draw_rules_3x3_combined(flip = FALSE)
seed |
The seed sequence. In most cases, the seed sequence is a single base pattern, which can be specified as a single letter, then 'rot' controls the initial rotation of the base pattern. It also supports a sequence with more than one base patterns as the seed sequence. In this case, it can be specified as a string of more than one base letters, then 'rot' can be set to a single rotation scalar which controls the rotation of the first letter, or a vector with the same length as the number of base letters. |
level |
Level of the curve. Currently it is restricted to an integer no bigger than 5. |
rot |
Rotation of the seed sequence, measured in the polar coordinate system, in degrees. |
flip |
The same setting as in ['sfc_3x3_peano()'] or ['sfc_3x3_meander()']. |
p |
An 'sfc_3x3_combined' object. |
code |
Ignore. The traverse codes are selected randomly. |
This type of 3x3 curve uses the combintation of base patterns from both the Peano curve and the Meander curve. On each level, the traverse path is randomly selected.
'sfc_3x3_combined()' returns an 'sfc_3x3_combined' object.
draw_multiple_curves(
sfc_3x3_combined("I", level = 3),
sfc_3x3_combined("I", level = 3),
sfc_3x3_combined("I", level = 3),
nrow = 1
)
draw_rules_3x3_combined()
draw_rules_3x3_combined(flip = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.