Learn R Programming

sfcurve (version 1.0.0)

sfc_expand,sfc_2x2-method: Expand the curve to the next level

Description

Expand the curve to the next level

Usage

# S4 method for sfc_2x2
sfc_expand(p, code, flip = FALSE)

# S4 method for sfc_3x3_peano sfc_expand(p, code = 1, flip = FALSE)

# S4 method for sfc_3x3_meander sfc_expand(p, code, flip = FALSE)

Value

An object in the same class as the input.

Arguments

p

An sfc_2x2 object or other related objects.

code

Expansion code, a single integer.

flip

Whethe to flip level-1 units? The value should be a logical vector of length one or the same as the length of p.

Details

For the Hilbert curve and Meander curve, as long as the expansion code of the first base pattern in the sequence is determinted, the expansion codes for other base patterns in the sequence are all determined. For the Peano curve, since there is only one traverse path on any level, code is ignored.

These functions are mainly used internally.

Examples

Run this code
p = sfc_2x2("I", 11)
sfc_expand(p, 2) # I|211
p = sfc_3x3_peano("I", 11)
sfc_expand(p, 2) # I|211
p = sfc_3x3_meander("I", 11)
sfc_expand(p, 2) # I|211

Run the code above in your browser using DataLab