Learn R Programming

sfcurve (version 1.0.0)

sfc_is_compatible,sfc_sequence,sfc_sequence-method: Whether two sfc_sequence objects are compatible

Description

Whether two sfc_sequence objects are compatible

Usage

# S4 method for sfc_sequence,sfc_sequence
sfc_is_compatible(p1, p2, strict = TRUE)

# S4 method for sfc_sequence,sfc_rules sfc_is_compatible(p1, p2)

# S4 method for sfc_rules,sfc_sequence sfc_is_compatible(p1, p2)

Value

A logical scalar.

Arguments

p1

An sfc_sequence object.

p2

An sfc_sequence object.

strict

TRUE or FALSE, see Details.

Details

The function compares whether the two universe base pattern sets are identical. If strict is TRUE, the order of the two universe sets should also be the same. If strict is FALSE, the universe set of p2 can be a subset of the universe set of p1.

Examples

Run this code
p1 = sfc_2x2("I")
p2 = sfc_2x2("R")
sfc_is_compatible(p1, p2)

p1 = sfc_2x2("I")
p2 = sfc_sequence("R")
sfc_is_compatible(p1, p2)
sfc_is_compatible(p1, p2, strict = FALSE)

p1 = sfc_sequence("ABC")
p2 = sfc_sequence("DEF")
sfc_is_compatible(p1, p2)

Run the code above in your browser using DataLab