| sfc_validate,sfc_sequence-method | R Documentation |
Validate the sequence
## S4 method for signature 'sfc_sequence'
sfc_validate(p, by = "sfc_2x2")
## S4 method for signature 'character'
sfc_validate(p, by = "sfc_2x2")
p |
An 'sfc_sequence' object or a character string. If it is a character string, rotation of zero is assigned to the first letter. |
by |
One of 'sfc_2x2', 'sfc_3x3_peano' and 'sfc_3x3_meander'. |
It is mainly used to validate a seed sequence whether they follow the forward-left-right rule.
A logical scalar.
try(sfc_validate("LLLLL"))
try(sfc_validate(sfc_sequence("IIIII", rot = c(0, 90, 180, 270, 0),
universe = sfc_universe(SFC_RULES_2x2))))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.