sfcurve-package: sfcurve: 2x2, 3x3 and Nxn Space-Filling Curves

sfcurve-packageR Documentation

sfcurve: 2x2, 3x3 and Nxn Space-Filling Curves

Description

Implementation of all possible forms of 2x2 and 3x3 space-filling curves, i.e., the generalized forms of the Hilbert curve https://en.wikipedia.org/wiki/Hilbert_curve, the Peano curve https://en.wikipedia.org/wiki/Peano_curve and the Peano curve in the meander type (Figure 5 in https://eudml.org/doc/141086). It can generates nxn curves expanded from any specific level-1 units. It also implements the H-curve and the three-dimensional Hilbert curve. See \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2412.16962")} for more details.

Details

Please go to the package's website: https://jokergoo.github.io/sfcurve/ for more details.

Author(s)

Maintainer: Zuguang Gu guzuguang@suat-sz.edu.cn (ORCID)

See Also

Useful links:


sfcurve documentation built on April 10, 2026, 5:06 p.m.