A three-column matrix of coordinates of points on the 3D Hilbert curve.
Arguments
level
The level of the curve.
Details
There are many forms of 3D Hilbert curve. Here we only implement one specific form.
See Also
Michael Bader. Space-Filling Curves: An Introduction with Applications in Scientific Computing, Springer Science & Business Media, 2012. tools:::Rd_expr_doi("10.1007/978-3-642-31046-1").