# S4 method for sfc_3x3_meander
sfc_expand(p, code, flip = FALSE)
Value
An object in the same class as the input.
Arguments
p
An sfc_2x2 object or other related objects.
code
Expansion code, a single integer.
flip
Whethe to flip level-1 units? The value should be a logical vector of length one or the same as the length of p.
Details
For the Hilbert curve and Meander curve, as long as the expansion code of the first base pattern in the sequence is determinted,
the expansion codes for other base patterns in the sequence are all determined. For the Peano curve, since
there is only one traverse path on any level, code is ignored.